@@ -1,3 +1,10 @@
+
+# NOTE: log_conf is imported first to initialize the loggers before they are created
+from .helpers import log_conf  # pylint: disable=unused-import
+
+# isort: split
+# pylint: disable=wrong-import-order,ungrouped-imports
+
 import asyncio
 import logging
 import ssl
@@ -14,7 +21,6 @@ from socketio import AsyncClient
 
 from .data_classes import NodeStatus
 from .data_exchanger import DataExchanger
-from .helpers import log_conf
 from .helpers.misc import ensure_socket_response, read_or_create_uuid
 from .loop_communication import LoopCommunicator
 from .rest import router
@@ -39,7 +45,6 @@ class Node(FastAPI):
         """
 
         super().__init__(lifespan=self.lifespan)
-        log_conf.init()
 
         self.name = name
         self.uuid = uuid or read_or_create_uuid(self.name)
@@ -68,6 +73,16 @@ class Node(FastAPI):
 
         self.repeat_loop_lock = asyncio.Lock()
 
+        self.previous_state: Optional[str] = None
+        self.repeat_loop_cycle_sec = 5
+
+    def log_status_on_change(self, current_state_str: str, full_status: Any):
+        if self.previous_state != current_state_str:
+            self.previous_state = current_state_str
+            self.log.info('Status changed to %s', full_status)
+        else:
+            self.log.debug('sending status %s', full_status)
+
     def init_loop_communicator(self):
         self.loop_communicator = LoopCommunicator()
         self.websocket_url = self.loop_communicator.websocket_url()
@@ -98,13 +113,14 @@ class Node(FastAPI):
                     pass
 
     async def _on_startup(self):
-        self.log.info('received "startup" lifecycle-event')
+        self.log.info('received "startup" lifecycle-event - connecting to loop')
         try:
             await self.reconnect_to_loop()
         except Exception:
             self.log.warning('Could not establish sio connection to loop during startup')
-        self.log.info('done')
+        self.log.info('successfully connected to loop - calling on_startup')
         await self.on_startup()
+        self.log.info('successfully finished on_startup')
 
     async def _on_shutdown(self):
         self.log.info('received "shutdown" lifecycle-event')
@@ -126,10 +142,12 @@ class Node(FastAPI):
                     await self.on_repeat()
             except asyncio.CancelledError:
                 return
+            except TimeoutError:
+                self.log.debug('Backend not ready within timeout, skipping repeat loop')
             except Exception:
                 self.log.exception('error in repeat loop')
 
-            await asyncio.sleep(5)
+            await asyncio.sleep(self.repeat_loop_cycle_sec)
 
     async def _ensure_sio_connection(self):
         if self.socket_connection_broken or self._sio_client is None or not self.sio_client.connected:
@@ -140,6 +158,7 @@ class Node(FastAPI):
     async def reconnect_to_loop(self):
         """Initialize the loop communicator, log in if needed and reconnect to the loop via socket.io."""
         self.init_loop_communicator()
+        await self.loop_communicator.backend_ready(timeout=5)
         if self.needs_login:
             await self.loop_communicator.ensure_login(relogin=True)
         try:
@@ -162,7 +181,8 @@ class Node(FastAPI):
         The current client is disconnected and deleted if it already exists."""
 
         self.log.debug('-------------- Connecting to loop via socket.io -------------------')
-        self.log.debug('HTTP Cookies: %s\n', self.loop_communicator.get_cookies())
+        cookies = self.loop_communicator.get_cookies()
+        self.log.debug('HTTP Cookies: %s\n', cookies)
 
         if self._sio_client is not None:
             try:
@@ -185,8 +205,12 @@ class Node(FastAPI):
             ssl_context.verify_mode = ssl.CERT_REQUIRED
             connector = TCPConnector(ssl=ssl_context)
 
-        self._sio_client = AsyncClient(request_timeout=20, http_session=aiohttp.ClientSession(
-            cookies=self.loop_communicator.get_cookies(), connector=connector))
+        if self.needs_login:
+            self._sio_client = AsyncClient(request_timeout=20, http_session=aiohttp.ClientSession(
+                cookies=cookies, connector=connector))
+        else:
+            self._sio_client = AsyncClient(request_timeout=20, http_session=aiohttp.ClientSession(
+                connector=connector))
 
         # pylint: disable=protected-access
         self._sio_client._trigger_event = ensure_socket_response(self._sio_client._trigger_event)
