@@ -1,6 +1,4 @@
-import asyncio
-
-from ....data_classes import TrainerState
+from ....enums import TrainerState
 from ...test_helper import condition
 from ..state_helper import assert_training_state, create_active_training_file
 from ..testing_trainer_logic import TestingTrainerLogic
